#!/usr/bin/perl -w

use strict;

use lib './lib';

use Net::Abuse::Utils qw/get_malware/;
use Data::Dumper;


my $hash = '733a48a9cb49651d72fe824ca91e8d00';
my $ret = get_malware($hash);

warn Dumper($ret);
